@@ -28,8 +28,6 @@ from __future__ import absolute_import, print_function
 
 import pytest
 
-from dictdiffer.merge import Merger, UnresolvedConflictsException
-
 from json_merger.config import DictMergerOps
 from json_merger.conflict import Conflict, ConflictType
 from dictdiffer.conflict import Conflict as Dictdiffer_Conflict
@@ -89,6 +87,18 @@ def test_merge_with_nothing():
     m.merge()
     assert m.merged_root == {'some': 'other object'}
 
+    m = SkipListsMerger({'some': 'other object'},
+                        NOTHING, {'some': 'other object'},
+                        DictMergerOps.FALLBACK_KEEP_HEAD)
+    m.merge()
+    assert m.merged_root == NOTHING
+
+    m = SkipListsMerger({'some': 'other object'},
+                        {'some': 'other object'}, NOTHING,
+                        DictMergerOps.FALLBACK_KEEP_HEAD)
+    m.merge()
+    assert m.merged_root == NOTHING
+
 
 def test_simple_conflicts_keep_head():
     r = {}
